@@ -842,7 +842,8 @@ class ProvPopTable(pd.DataFrame):
                 # sex and age already
                 flag = False
             )
-            flag = True
+            # `flag` is True iff `I` has at least one nonzero value
+            flag = (sum(self_cp_sex.get_I()['I'].values != 0) != 0)
             i = 0
             num_zeros = sum(self_cp_sex.get_I()['I'].values == 0)
             while flag:
@@ -1103,7 +1104,8 @@ class ProvPopTable(pd.DataFrame):
         '''
         Return how much modification and counter-adjustments the records of
         `self` can absorb in the `comp` component for the youngest 
-        problematic record.
+        problematic record. In case where `self` doesn't need a correction,
+        it throws an IndexError.
 
         Usage
         -----
@@ -1136,7 +1138,7 @@ class ProvPopTable(pd.DataFrame):
         comps = comp_neg + comp_pos
         raise_if_not_subset([comp], comps, 'comp', 'components of self')
         at_least = get_option('pop.at_least')
-        pop_groups = [self.__pop_sex, self.__pop_age]
+        pop_groups = self.get_pop_groups()
         cols_required = pop_groups.copy()
         cols_required.append(comp)
 
