@@ -11,6 +11,7 @@ from estime2 import (
     Age,
     get_option,
     options,
+    set_option,
     ProvPopTable
 )
 from estime2.provpoptable import calculate_ages_to_modify_and_counter
@@ -843,4 +844,8 @@ def run5():
         ):
             poptbl_regions[region] = estime2.ProvPopTable(tbl_region)
     
-    return poptbl_regions
\ No newline at end of file
+    return poptbl_regions
+
+def run6():
+    pass
+
